"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const agentBase = require("agent-base");
const tls = require("tls");
/**
 * Construct an agent for http(s) requests. Mostly for testing purposes.
 *
 * @param proxy - the proxy to use
 * @param options - to set additional TLS options for https requests, e.g. rejectUnauthorized
 */
function proxyAgent(proxy, options) {
    return agentBase((req, opts) => __awaiter(this, void 0, void 0, function* () {
        const socket = yield proxy.connect(opts);
        if (opts.secureEndpoint) {
            // Upgrade to TLS
            let tlsOptions = {
                socket: socket,
                servername: opts.servername || opts.host
            };
            if (typeof opts.rejectUnauthorized != 'undefined') {
                // There's a difference between 'undefined' (equivalent of false) and "not set" (equivalent of true)
                tlsOptions.rejectUnauthorized = opts.rejectUnauthorized;
            }
            Object.assign(tlsOptions, options);
            const tlsSocket = tls.connect(tlsOptions);
            return tlsSocket;
        }
        else {
            socket.resume();
            return socket;
        }
    }));
}
exports.proxyAgent = proxyAgent;
